# Introduction

OpenCloud is an open-source, distributed cloud solution that enables you to selectively share, sell, or rent your infrastructure resources—such as data, algorithms, compute power, and storage with other OpenCloud peers. It facilitates distributed workflow execution between partners, allowing seamless collaboration across decentralized networks.

Distributed execution within this peer-to-peer network can be optimized according to your own priorities:

* **Maximal sovereignty**
* **Accelerated computation**
* **Cost minimization**
* **Optimized infrastructure investments**

Each OpenCloud instance includes an OpenID-based distributed authentication system. 
OpenCloud is entirely decentralized, with no central authority or single point of failure (SPOF). Additionally, OpenCloud provides transaction tracking, allowing all partners to be aware of their distributed resource consumption and ensuring transparent peer-to-peer billing.

---

## Features

Each OpenCloud instance runs a collection of services that allow users to interact with both their own deployment and other OpenCloud participants.

### Resource Catalog

The **Resource Catalog** service indexes all the resources provided by the current instance, including **Data**, **Algorithms**, **Compute Units**, **Storages**, and pre-built **Processing Workflows**.
All resources are described by metadata, as defined in the `catalog_metadata` document. Catalog resources can be either **public**, visible to all OpenCloud peers, or **private**, accessible only to selected partners or groups (e.g., projects, entities, etc.).
Access to specific resources may require credentials, payment, or other access agreements.

---

### Workspace Management

Each OpenCloud user can create **workspaces** to organize resources of interest.
Resources within a workspace can later be used to build processing workflows or set up new services.
Users can define as many workspaces as needed to manage their projects efficiently.

---

### Workflow Editor

Using elements selected in a workspace, a user can build a **distributed processing workflow** or establish a **permanent service**.
Workflows are constructed with OpenCloud's integrated workflow editor, offering a user-friendly interface for defining distributed processes.

---

### Collaborative Areas

OpenCloud enables the sharing of **workspaces** and **workflows** with selected partners, enhancing collaborative projects.
A **Collaborative Area** can include multiple management and operation rules that are enforced automatically or verified manually. Examples include:

* Enforcing the use of only open-source components
* Restricting the inclusion of personal data
* Defining result visibility constraints
* Imposing legal limitations

---

### Peer Management

OpenCloud allows you to define relationships with other peers, enabling the creation of private communities.
Access rights related to peers can be managed at a **global peer scope** or for **specific groups** within the peer community.

---

## Benefits

### Complete Control Over Data Location

OpenCloud encourages users to host their own data.
When external storage is necessary, OpenCloud enables users to carefully select partners and locations to ensure privacy, compliance, and performance.

---

### Cooperation Framework

OpenCloud provides a structured framework for sharing data, managing common workspaces, and defining usage regulations.
This framework covers both **technical** and **legal aspects** for distributed projects.

---

### Data Redundancy

Like traditional public cloud architectures, OpenCloud supports **data redundancy** but with finer-grained control.
You can distribute your data across multiple OpenCloud instances, ensuring availability and resilience.

---

### Compatibility with Public Cloud Infrastructure

When your workloads require massive storage or computational capabilities beyond what your OpenCloud peers can provide, you can seamlessly deploy an OpenCloud instance on any public cloud provider.
This hybrid approach allows you to scale effortlessly for workloads that are not sensitive to international competition.

---

### Fine-Grained Access Control

OpenCloud provides **fine-grained access control**, enabling you to precisely define access policies for partners and communities.

---

### Lightweight for Datacenter and Edge Deployments

The OpenCloud stack is developed in **Go**, generating **native code** and minimal **scratch containers**. All selected COTS (Commercial Off-The-Shelf) components used by OpenCloud services are chosen with these design principles in mind.

The objective is to enable OpenCloud to run on almost any platform:

* In **datacenters**, supporting large-scale processing workflows
* On **ARM-based single-board computers**, handling concurrent payloads for diverse applications like **sensor preprocessing**, **image recognition**, or **data filtering**

GUIs are built with **Flutter** and rendered as plain **HTML/JS** for lightweight deployment.

---

### Fully Distributed Architecture

OpenCloud is fully decentralized, eliminating any **single point of failure**.
There is no central administrator, and no central registration is required. This makes OpenCloud highly **resilient**, allowing partners to join or leave the network without impacting the broader OpenCloud community.

---

### Open Source and Transparent

To foster trust, OpenCloud is released as **open-source software**.
Its code is publicly available for audit. The project is licensed under **AGPL V3** to prevent the emergence of closed, private forks that could compromise the OpenCloud community's transparency and trust.

